@@ -1010,7 +1010,10 @@ class MeshgridDataDict(DataDictBase):
 
         shp = None
         shpsrc = ''
-        for n, v in self.data_items():
+
+        data_items = dict(self.data_items())
+
+        for n, v in data_items.items():
             if type(v['values']) not in [np.ndarray, np.ma.core.MaskedArray]:
                 self[n]['values'] = np.array(v['values'])
 
@@ -1023,6 +1026,17 @@ class MeshgridDataDict(DataDictBase):
                     msg += f" {v['values'].shape}, "
                     msg += f"and '{shpsrc}' has {shp}.\n"
 
+            if 'axes' in v:
+                for axis_num, na in enumerate(v['axes']):
+                    # check that the data of the axes matches its use
+                    # if data present
+                    axis_data = data_items[na]['values']
+                    if axis_data.size > 0:
+                        max_step_along_axes = np.max(np.abs(np.diff(data_items[na]['values'],axis=axis_num)))
+                        if max_step_along_axes == 0:
+                            msg += (f"Malformed data: {na} is expected to be {axis_num}th "
+                                     "axis but has no variation along that axis.\n")
+
             if msg != '\n':
                 raise ValueError(msg)
 
@@ -1087,7 +1101,7 @@ def guess_shape_from_datadict(data: DataDict) -> \
 
 def datadict_to_meshgrid(data: DataDict,
                          target_shape: Union[Tuple[int, ...], None] = None,
-                         inner_axis_order: Union[None, List[str]] = None,
+                         inner_axis_order: Union[None, Sequence[str]] = None,
                          use_existing_shape: bool = False) \
         -> MeshgridDataDict:
     """
